我的設置 - kxx.moe

| 帳號信息 |  | 推送設置 |  | 真實驗證 |  | 訂閱收藏 |  | 額度記錄 |  | 相關書評 |  | 製作漫畫 |

登錄郵箱 : | holdjohnh@gmail.com ( KMOE ID : 10756186 )
昵稱 : | holdjohnh
頭像 : | 支持JPEG / PNG
信息主頁背景 : | 在信息主頁頂部展示，支持JPEG / PNG，截取中間部分延展至 2000*250px 顯示
信息主頁默認分類 : |
默認顯示的操作 : |
瀏覽及搜索時忽略分類 : | 僅忽略頁數少於 2000 頁(約10卷)的短篇中篇作品
| 你是本站 Lv3 用戶，且是本站 VIP ， VIP開通日期 2022-06-25，VIP期限至 2023-06-24。 VIP 額度 : 每月 25 日 0 時更新 , 每月額度為 0G (= 0.0 M) 。 Lv3 額度 : 每月 10 日 0 時更新 , 每月額度為 3G (= 3072.0 M) 。 今日已用 : 810.7 M , 本月已用免費額度 : 1584.5 M , 本月已經用VIP額度 : 0.0 M Lv3 每月額度 : 3072.0 M , 剩餘 : 1487.5 M , VIP 每月額度 : 0.0 M , 剩餘 : 0.0 M , 額外額度剩餘 : 0.0 M 你是本站 Lv3 用戶。每月 10 日 0 時更新額度 , 每月可下載/推送總文件大小為 3G (= 3072.0 M) 。 今日已用 : 810.7 M , 本月已用額度 : 1584.5 M 每月免費額度 : 3072.0 M , 剩餘 : 1487.5 M , 額外額度剩餘 : 0.0 M Lv3 用戶每天額度 : 300.0 M , 今天剩餘 : 0.0 M
| 捐助成為VIP : 每月 40G 下載額度，及可使用VIP下載線路。 VIP 免費領取漫畫卡片，僅付郵費寄全國
| Lv1 : 每月 2G 額度，且每日最多使用 300M 額度，下載限速，普通線路。
| Lv2 : 每月 2G 額度，無每日限額，下載限速，普通線路。(要求: 驗證Kindle郵箱 或 驗證手機號碼)
| Lv3 : 每月 3G 額度，無每日限額，下載限速，普通線路。(要求: 達到 Lv2 後滿 90 天)
| Lv4 : 每月 5G 額度，無每日限額，下載限速，普通線路。(要求: 上傳一定數量漫畫，看站長心情開通)
| VIP : 每月40G 額度，無每日限額，全球優化下載線路。(若開通多月則額度在每月開通日更新)
| 注 1 : 訂閱連載中的漫畫，有更新時自動推送的卷(冊)，暫不計算在使用額度中，不扣減使用額度。
| 注 2 : 對同一卷(冊)書*同一格式*文檔在 24 小時內重複*下載*，不會重複扣減額度。不同格式或重復推送是會扣減的。

本站內容均由網友上傳，如有疑問或爭議請聯繫 mail@kmoe.one
≡　2026　Kmoe ｜ kxx.moe kzz.moe koz.moe≡